@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2019 - 2023 Advanced Micro Devices, Inc. All rights reserved.
+Copyright (c) 2019 - 2025 Advanced Micro Devices, Inc. All rights reserved.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -23,6 +23,7 @@ THE SOFTWARE.
 #ifndef MIVISIONX_ROCAL_API_META_DATA_H
 #define MIVISIONX_ROCAL_API_META_DATA_H
 #include "rocal_api_types.h"
+#include <set>
 
 /*!
  * \file
@@ -316,4 +317,24 @@ extern "C" void ROCAL_API_CALL rocalBoxIouMatcher(RocalContext p_context, std::v
  */
 extern "C" RocalTensorList ROCAL_API_CALL rocalGetMatchedIndices(RocalContext p_context);
 
+/*! \brief creates webdataset reader
+ * \ingroup group_rocal_meta_data
+ * \param [in] p_context rocal context
+ * \param [in] source_path path to the folder that contains the dataset
+ * \param [in] index_path path to the folder that contains the index files
+ * \param extensions [in] the extensions used in the tar files for parsing them
+ * \param missing_components_behavior [in] The behaviour that determines what happens when any component in the sample is missing.
+ * \param is_output [in] The output is set or not.
+ * \return RocalMetaData object, can be used to inquire about the rocal's output (processed) tensors
+ */
+extern "C" RocalMetaData ROCAL_API_CALL rocalCreateWebDatasetReader(RocalContext p_context, const char* source_path, const char* index_path,
+                                                                    std::vector<std::set<std::string>> extensions, RocalMissingComponentsBehaviour missing_components_behavior, bool is_output);
+
+/*! \brief get joints data pointer
+ * \ingroup group_rocal_meta_data
+ * \param [in] rocal_context rocal context
+ * \param [out] ascii_data The user's AsciiDatas pointer that will be pointed to AsciiDataBatch pointer
+ */
+RocalMetaData ROCAL_API_CALL rocalGetAsciiDatas(RocalContext p_context);
+
 #endif  // MIVISIONX_ROCAL_API_META_DATA_H
